/***************************************************************************
                          kbibselectentrytype  -  description
                             -------------------
    begin                : Fri Apr 9 2004
    copyright            : (C) 2004 by Thach Nguyen
    email                : thach.nguyen@rmit.edu.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KBIBSELECTENTRYTYPE_H
#define KBIBSELECTENTRYTYPE_H

#include <kdialogbase.h>
#include <kcombobox.h> 
#include <qlabel.h>

/**
@author Thach Nguyen
*/
class KbibSelectEntryType : public KDialogBase
{
Q_OBJECT
public:
    KbibSelectEntryType(QWidget *parent = 0, const char *name = 0);

    ~KbibSelectEntryType();
    
    QString get_entryType(void);
    
private:
	QLabel *elabel;
	KComboBox *entryList;

};

#endif
